period
======

Period is a basic time period checking library.

Period is based on period.py by William S. Annis. (available at
https://www.biostat.wisc.edu/~annis/creations/period.py.html)
and ported to python3 with a few improvements. Period.py was in part inspired
by perl's Time::Period module and the time class mechanism of Cfengine.
